#' @importFrom precrec

library(testthat)

test_check("precrec")
